@@ -1,7 +1,11 @@
-<?PHP  // $Id: dbperformance.php,v 1.1 2003/11/19 08:15:23 moodler Exp $
+<?PHP  // $Id: dbperformance.php,v 1.4 2006/03/06 10:02:59 skodak Exp $
        // dbperformance.php - shows latest ADOdb stats for the current server
 
-    require_once("../config.php");
+    require_once('../config.php');
+
+    $topframe    = optional_param('topframe', 0, PARAM_BOOL);
+    $bottomframe = optional_param('bottomframe', 0, PARAM_BOOL);
+    $do          = optional_param('do', '', PARAM_ALPHA);
 
     require_login();
 
@@ -13,13 +17,13 @@
     $stradministration = get_string("administration");
     $site = get_site();
 
-    if (isset($topframe)) {
-	    print_header("$site->shortname: $strdatabaseperformance", "$site->fullname", 
+    if (!empty($topframe)) {
+        print_header("$site->shortname: $strdatabaseperformance", "$site->fullname", 
                      "<a target=\"$CFG->framename\" href=\"index.php\">$stradministration</a> -> Database performance");
         exit;
     }
 
-    if (isset($bottomframe) or isset($_GET['do'])) {
+    if (!empty($bottomframe) or !empty($do)) {
         $perf =&NewPerfMonitor($db);
         $perf->UI($pollsecs=5);
         exit;
