@@ -1,4 +1,4 @@
-<?php // $Id: index.php,v 1.86.2.7 2006/08/30 08:04:43 skodak Exp $
+<?php // $Id: index.php,v 1.86.2.9 2006/10/03 18:13:47 gustav_delius Exp $
 
 //  Manage all uploaded files in a course file area
 
@@ -167,7 +167,7 @@
                 // um will take care of error reporting.
                 displaydir($wdir);
             } else {
-                $upload_max_filesize = get_max_upload_file_size($CFG->maxbytes, $course->maxbytes);
+                $upload_max_filesize = get_max_upload_file_size($CFG->maxbytes);
                 $filesize = display_size($upload_max_filesize);
 
                 $struploadafile = get_string("uploadafile");
@@ -385,6 +385,7 @@
             html_header($course, $wdir);
             if (($text != '') and confirm_sesskey()) {
                 $fileptr = fopen($basedir.'/'.$file,"w");
+                $text = preg_replace('/\x0D/', '', $text);  // http://moodle.org/mod/forum/discuss.php?d=38860
                 fputs($fileptr, stripslashes($text));
                 fclose($fileptr);
                 displaydir($wdir);
