@@ -1,9 +1,7 @@
 <?php
 
-// $CVSHeader$
-
 /*
-V4.01 23 Oct 2003  (c) 2000-2004 John Lim (jlim@natsoft.com.my). All rights reserved.
+V4.71 24 Jan 2006  (c) 2000-2006 John Lim (jlim@natsoft.com.my). All rights reserved.
          Contributed by Ross Smith (adodb@netebb.com). 
   Released under both BSD license and Lesser GPL library license.
   Whenever there is any discrepancy between the two licenses,
@@ -12,6 +10,9 @@ V4.01 23 Oct 2003  (c) 2000-2004 John Lim (jlim@natsoft.com.my). All rights rese
 
 */
 
+// security - hide paths
+if (!defined('ADODB_SESSION')) die();
+
 include_once ADODB_SESSION . '/crypt.inc.php';
 
 /**
