@@ -1,4 +1,4 @@
-<?php //$Id: pagelib.php,v 1.33.2.2 2005/11/21 13:18:03 stronk7 Exp $
+<?php //$Id: pagelib.php,v 1.40.2.1 2006/07/19 07:59:16 skodak Exp $
 
 /**
  * This file contains the parent class for moodle pages, page_base, 
@@ -7,7 +7,7 @@
  * (courseid, blogid, activity id, etc).
  *
  * @author Jon Papaioannou
- * @version  $Id: pagelib.php,v 1.33.2.2 2005/11/21 13:18:03 stronk7 Exp $
+ * @version  $Id: pagelib.php,v 1.40.2.1 2006/07/19 07:59:16 skodak Exp $
  * @license http://www.gnu.org/copyleft/gpl.html GNU Public License
  * @package pages
  */
@@ -297,6 +297,12 @@ class page_base {
     function init_full() {
         $this->full_init_done = true;
     }
+
+
+    // is this  page always editable, regardless of anything else?
+    function edit_always() {
+        return (isadmin() &&  defined('ADMIN_STICKYBLOCKS'));
+    }
 }
 
 
@@ -317,7 +323,7 @@ class page_course extends page_base {
     // Do any validation of the officially recognized bits of the data and forward to parent.
     // Do NOT load up "expensive" resouces (e.g. SQL data) here!
     function init_quick($data) {
-        if(empty($data->pageid)) {
+        if(empty($data->pageid) && !defined('ADMIN_STICKYBLOCKS')) {
             error('Cannot quickly initialize page: empty course id');
         }
         parent::init_quick($data);
@@ -331,8 +337,11 @@ class page_course extends page_base {
         if($this->full_init_done) {
             return;
         }
+        if (empty($this->id)) {
+            $this->id = 0; // avoid db errors
+        }
         $this->courserecord = get_record('course', 'id', $this->id);
-        if(empty($this->courserecord)) {
+        if(empty($this->courserecord) && !defined('ADMIN_STICKYBLOCKS')) {
             error('Cannot fully initialize page: invalid course id '. $this->id);
         }
         $this->full_init_done = true;
@@ -343,12 +352,18 @@ class page_course extends page_base {
     // When is a user said to have "editing rights" in this page? This would have something
     // to do with roles, in the future.
     function user_allowed_editing() {
+        if (isadmin() && defined('ADMIN_STICKYBLOCKS')) {
+            return true;
+        }
         return isteacheredit($this->id);
     }
 
     // Is the user actually editing this page right now? This would have something
     // to do with roles, in the future.
     function user_is_editing() {
+        if (isadmin() && defined('ADMIN_STICKYBLOCKS')) {
+            return true;
+        }
         return isediting($this->id);
     }
 
@@ -392,10 +407,11 @@ class page_course extends page_base {
 
         // The "Editing On" button will be appearing only in the "main" course screen
         // (i.e., no breadcrumbs other than the default one added inside this function)
-        $button = empty($morebreadcrumbs) ? update_course_icon($this->courserecord->id) : '&nbsp;';
+        $buttons = update_course_icon($this->courserecord->id ) . update_studentview_button( $this->courserecord->id );
+        $buttons = empty($morebreadcrumbs) ? $buttons : '&nbsp;';
 
         print_header($title, $this->courserecord->fullname, $crumbtext,
-                     '', '', true, $button, user_login_string($this->courserecord, $USER));
+                     '', '', true, $buttons, user_login_string($this->courserecord, $USER));
     }
 
     // SELF-REPORTING SECTION
@@ -411,6 +427,9 @@ class page_course extends page_base {
     // the format_name might be that activity's name etc.
     function get_format_name() {
         $this->init_full();
+        if (defined('ADMIN_STICKYBLOCKS')) {
+            return PAGE_COURSE_VIEW;
+        }
         if($this->id == SITEID) {
             return parent::get_format_name();
         }
@@ -420,6 +439,9 @@ class page_course extends page_base {
     // This should return a fully qualified path to the URL which is responsible for displaying us.
     function url_get_path() {
         global $CFG;
+        if (defined('ADMIN_STICKYBLOCKS')) {
+            return $CFG->wwwroot.'/'.$CFG->admin.'/stickyblocks.php';
+        }
         if($this->id == SITEID) {
             return $CFG->wwwroot .'/index.php';
         }
@@ -431,6 +453,9 @@ class page_course extends page_base {
     // This should return an associative array of any GET/POST parameters that are needed by the URL
     // which displays us to make it work. If none are needed, return an empty array.
     function url_get_parameters() {
+        if (defined('ADMIN_STICKYBLOCKS')) {
+            return array('pt' => ADMIN_STICKYBLOCKS);
+        }
         if($this->id == SITEID) {
             return array();
         }
@@ -470,7 +495,7 @@ class page_course extends page_base {
             }
             /// Failsafe - in case nothing was defined.
             else {
-                $blocknames = 'site_main_menu,admin,course_list:course_summary,calendar_month';
+                $blocknames = 'site_main_menu,admin:course_summary,calendar_month';
             }
         }
         // It's a normal course, so do it according to the course format
