@@ -1,4 +1,4 @@
-<?php // $Id: comments.php,v 1.13.2.1 2005/12/07 05:57:19 moodler Exp $
+<?php // $Id: comments.php,v 1.15.2.1 2006/08/10 15:30:49 skodak Exp $
 
 /// This page prints a particular instance of glossary
     require_once('../../config.php');
@@ -9,7 +9,7 @@
 
     global $USER, $CFG;
 
-    if (! $cm = get_record("course_modules", "id", $id)) {
+    if (! $cm = get_coursemodule_from_id('glossary', $id)) {
         error("Course Module ID was incorrect");
     }
 
@@ -54,7 +54,7 @@
 
 /// comments
 
-    print_heading(get_string('commentson','glossary')." <b>\"$entry->concept\"</b>");
+    print_heading(format_string(get_string('commentson','glossary')." <b>\"$entry->concept\"</b>"));
 
     if ($glossary->allowcomments || isteacher($glossary->course)) {
         print_heading("<a href=\"comment.php?id=$cm->id&amp;eid=$entry->id\">$straddcomment</a> <img title=\"$straddcomment\" src=\"comment.gif\" height=\"11\" width=\"11\" border=\"0\" alt=\"\" />");
