@@ -1,4 +1,4 @@
-<?php //$Id: restorelib.php,v 1.19.2.3 2005/11/23 09:39:31 stronk7 Exp $
+<?php //$Id: restorelib.php,v 1.26 2006/04/11 16:23:29 stronk7 Exp $
     //This php script contains all the stuff to backup/restore
     //workshop mods
 
@@ -138,9 +138,11 @@
             $newid = insert_record ("workshop",$workshop);
 
             //Do some output     
-            echo "<li>".get_string("modulename","workshop")." \"".format_string(stripslashes($workshop->name),true)."\"</li>";
+            if (!defined('RESTORE_SILENTLY')) {
+                echo "<li>".get_string("modulename","workshop")." \"".format_string(stripslashes($workshop->name),true)."\"</li>";
+            }
             backup_flush(300);
-
+            
             if ($newid) {
                 //We have the newid, update backup_ids
                 backup_putid($restore->backup_unique_code,$mod->modtype,
@@ -148,7 +150,7 @@
                 //We have to restore the workshop_elements table now (course level table)
                 $status = workshop_elements_restore_mods($newid,$info,$restore);
                 //Now check if want to restore user data and do it.
-                if ($restore->mods['workshop']->userinfo) {
+                if (restore_userdata_selected($restore,'workshop',$mod->id)) {
                     //Restore workshop_submissions
                     $status = workshop_submissions_restore_mods ($mod->id, $newid,$info,$restore);
                 }
@@ -194,9 +196,11 @@
 
             //Do some output
             if (($i+1) % 10 == 0) {
-                echo ".";
-                if (($i+1) % 200 == 0) {
-                    echo "<br />";
+                if (!defined('RESTORE_SILENTLY')) {
+                    echo ".";
+                    if (($i+1) % 200 == 0) {
+                        echo "<br />";
+                    }
                 }
                 backup_flush(300);
             }
@@ -244,9 +248,11 @@
 
                 //Do some output
                 if (($i+1) % 10 == 0) {
-                    echo ".";
-                    if (($i+1) % 200 == 0) {
-                        echo "<br />";
+                    if (!defined('RESTORE_SILENTLY')) {
+                        echo ".";
+                        if (($i+1) % 200 == 0) {
+                            echo "<br />";
+                        }
                     }
                     backup_flush(300);
                 }
@@ -288,9 +294,11 @@
 
                 //Do some output
                 if (($i+1) % 50 == 0) {
-                    echo ".";
-                    if (($i+1) % 1000 == 0) {
-                        echo "<br />";
+                    if (!defined('RESTORE_SILENTLY')) {
+                        echo ".";
+                        if (($i+1) % 1000 == 0) {
+                            echo "<br />";
+                        }
                     }
                     backup_flush(300);
                 }
@@ -348,9 +356,11 @@
 
             //Do some output
             if (($i+1) % 50 == 0) {
-                echo ".";
-                if (($i+1) % 1000 == 0) {
-                    echo "<br />";
+                if (!defined('RESTORE_SILENTLY')) {
+                    echo ".";
+                    if (($i+1) % 1000 == 0) {
+                        echo "<br />";
+                    }
                 }
                 backup_flush(300);
             }
@@ -422,9 +432,11 @@
 
                 //Do some output
                 if (($i+1) % 50 == 0) {
-                    echo ".";
-                    if (($i+1) % 1000 == 0) {
-                        echo "<br />";
+                    if (!defined('RESTORE_SILENTLY')) {
+                        echo ".";
+                        if (($i+1) % 1000 == 0) {
+                            echo "<br />";
+                        }
                     }
                     backup_flush(300);
                 }
@@ -491,9 +503,11 @@
 
                 //Do some output
                 if (($i+1) % 50 == 0) {
-                    echo ".";
-                    if (($i+1) % 1000 == 0) {
-                        echo "<br />";
+                    if (!defined('RESTORE_SILENTLY')) {
+                        echo ".";
+                        if (($i+1) % 1000 == 0) {
+                            echo "<br />";
+                        }
                     }
                     backup_flush(300);
                 }
@@ -537,9 +551,11 @@
 
                 //Do some output
                 if (($i+1) % 50 == 0) {
-                    echo ".";
-                    if (($i+1) % 1000 == 0) {
-                        echo "<br />";
+                    if (!defined('RESTORE_SILENTLY')) {
+                        echo ".";
+                        if (($i+1) % 1000 == 0) {
+                            echo "<br />";
+                        }
                     }
                     backup_flush(300);
                 }
@@ -633,9 +649,11 @@
                 //Do some output
                 $i++;
                 if (($i+1) % 1 == 0) {
-                    echo ".";
-                    if (($i+1) % 20 == 0) {
-                        echo "<br />";
+                    if (!defined('RESTORE_SILENTLY')) {
+                        echo ".";
+                        if (($i+1) % 20 == 0) {
+                            echo "<br />";
+                        }
                     }
                     backup_flush(300);
                 }
@@ -733,17 +751,21 @@
                     $workshop->description = addslashes($result);
                     $status = update_record("workshop",$workshop);
                     if ($CFG->debug>7) {
-                        echo '<br /><hr />'.htmlentities($content).'<br />changed to<br />'.htmlentities($result).'<hr /><br />';
+                        if (!defined('RESTORE_SILENTLY')) {
+                            echo '<br /><hr />'.s($content).'<br />changed to<br />'.s($result).'<hr /><br />';
+                        }
                     }
                 }
                 //Do some output
                 if (($i+1) % 5 == 0) {
-                    echo ".";
-                    if (($i+1) % 100 == 0) {
-                        echo "<br />";
+                    if (!defined('RESTORE_SILENTLY')) {
+                        echo ".";
+                        if (($i+1) % 100 == 0) {
+                            echo "<br />";
+                        }
                     }
                     backup_flush(300);
-                    }
+                }
             }
         }
 
@@ -928,7 +950,9 @@
             }
             break;
         default:
-            echo "action (".$log->module."-".$log->action.") unknow. Not restored<br />";                 //Debug
+            if (!defined('RESTORE_SILENTLY')) {
+                echo "action (".$log->module."-".$log->action.") unknown. Not restored<br />";                 //Debug
+            }
             break;
         }
 
